@@ -1,6 +1,8 @@
+// { dg-require-namedlocale "" }
+
 // 2001-08-27 Benjamin Kosnik  <bkoz@redhat.com>
 
-// Copyright (C) 2001, 2002, 2003, 2004 Free Software Foundation
+// Copyright (C) 2001, 2002, 2003, 2004, 2005 Free Software Foundation
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -15,7 +17,7 @@
 
 // You should have received a copy of the GNU General Public License along
 // with this library; see the file COPYING.  If not, write to the Free
-// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
+// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 // USA.
 
 // 22.2.6.2.1 money_put members
@@ -34,7 +36,7 @@ void test01()
 
   // basic construction
   locale loc_c = locale::classic();
-  locale loc_de = __gnu_test::try_named_locale("de_DE@euro");
+  locale loc_de = locale("de_DE@euro");
   VERIFY( loc_c != loc_de );
 
   // sanity check the data is correct.
