@@ -1,4 +1,6 @@
-// Copyright (C) 2003 Free Software Foundation, Inc.
+// { dg-require-namedlocale "" }
+
+// Copyright (C) 2003, 2005 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -13,7 +15,7 @@
 
 // You should have received a copy of the GNU General Public License along
 // with this library; see the file COPYING.  If not, write to the Free
-// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
+// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 // USA.
 
 // 27.8.1.4 Overridden virtual functions
@@ -21,29 +23,32 @@
 #include <fstream>
 #include <testsuite_hooks.h>
 
-const char name_01[] = "tmp_11389-1";
+const char name_04[] = "tmp_11389-4";
 
-void test01()
+void test04()
 {
   using namespace std;
   bool test __attribute__((unused)) = true;
 
   filebuf fbout;
-  fbout.open(name_01, ios_base::out);
+  fbout.open(name_04, ios_base::out);
   fbout.sputc('a');
+  fbout.sputc('b');
   fbout.close();
   
   wfilebuf fbin;
-  locale loc(__gnu_test::try_named_locale("en_US.UTF-8"));
+  locale loc(locale("en_US.UTF-8"));
   fbin.pubimbue(loc);
-  fbin.open(name_01, ios_base::in);
+  fbin.pubsetbuf(0, 0);
+  fbin.open(name_04, ios_base::in);
   VERIFY( fbin.sbumpc() == L'a' );
+  VERIFY( fbin.sbumpc() == L'b' );
   VERIFY( fbin.sgetc() == wfilebuf::traits_type::eof() );
   fbin.close();
 }
 
 int main()
 {
-  test01();
+  test04();
   return 0;
 }
