@@ -1,7 +1,7 @@
 // -*- C++ -*-
 // Utility subroutines for the C++ library testsuite. 
 //
-// Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005
+// Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006
 // Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
@@ -17,7 +17,7 @@
 //
 // You should have received a copy of the GNU General Public License along
 // with this library; see the file COPYING.  If not, write to the Free
-// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
+// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 // USA.
 //
 // As a special exception, you may use this file as part of a free software
@@ -52,9 +52,6 @@
 // 4)  copy_tracker, from Stephen M. Webb <stephen@bregmasoft.com>.
 //   A class with nontrivial ctor/dtor that provides the ability to track the
 //   number of copy ctors and dtors, and will throw on demand during copy.
-//
-// 5) pod_char, pod_int, , abstract character classes and
-//   char_traits specializations for testing instantiations.
 
 #ifndef _GLIBCXX_TESTSUITE_HOOKS_H
 #define _GLIBCXX_TESTSUITE_HOOKS_H
@@ -63,7 +60,6 @@
 #include <bits/functexcept.h>
 #include <cstddef>
 #include <locale>
-#include <ext/pod_char_traits.h>
 #ifdef _GLIBCXX_HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
@@ -108,10 +104,9 @@ namespace __gnu_test
   // bitmask_operators
   template<typename bitmask_type>
     void
-    bitmask_operators()
+    bitmask_operators(bitmask_type a = bitmask_type(),
+		      bitmask_type b = bitmask_type())
     {
-      bitmask_type a;
-      bitmask_type b;
       a | b;
       a & b;
       a ^ b;
@@ -164,37 +159,22 @@ namespace __gnu_test
   void 
   run_tests_wrapped_env(const char*, const char*, const func_callback&);
 
-  // Try to create a locale with the given name. If it fails, bail.
-  std::locale
-  try_named_locale(const char* name);
 
-  int
-  try_mkfifo (const char* filename, mode_t mode);
-
-  // Test data types.
-  struct pod_char
+  // For containers (23.1/3).
+  struct NonDefaultConstructible
   {
-    unsigned char c;
+    NonDefaultConstructible(int) { }
   };
+ 
+  inline bool
+  operator==(const NonDefaultConstructible&,
+	     const NonDefaultConstructible&)
+  { return false; }
 
   inline bool
-  operator==(const pod_char& lhs, const pod_char& rhs)
-  { return lhs.c == rhs.c; }
-  
-  struct pod_int
-  {
-    int i;
-  };
-  
-  struct state
-  {
-    unsigned long l;
-    unsigned long l2;
-  };
-
-  typedef unsigned short				value_type;
-  typedef unsigned int					int_type;
-  typedef __gnu_cxx::character<value_type, int_type>	pod_type;
+  operator<(const NonDefaultConstructible&,
+	    const NonDefaultConstructible&)
+  { return false; }
 
 
   // Counting.
@@ -405,105 +385,12 @@ namespace __gnu_test
 
     pid_t pid_;
   };
+
+  // For use in 22_locale/time_get and time_put.
+  tm test_tm(int sec, int min, int hour, int mday, int mon,
+	     int year, int wday, int yday, int isdst);
+
 } // namespace __gnu_test
 
-namespace std
-{
-  template<class _CharT>
-    struct char_traits;
-
-  // char_traits specialization
-  template<>
-    struct char_traits<__gnu_test::pod_char>
-    {
-      typedef __gnu_test::pod_char	char_type;
-      typedef __gnu_test::pod_int  	int_type;
-      typedef __gnu_test::state   	state_type;
-      typedef fpos<state_type> 		pos_type;
-      typedef streamoff 		off_type;
-      
-      static void 
-      assign(char_type& c1, const char_type& c2)
-      { c1.c = c2.c; }
-
-      static bool 
-      eq(const char_type& c1, const char_type& c2)
-      { return c1.c == c2.c; }
-
-      static bool 
-      lt(const char_type& c1, const char_type& c2)
-      { return c1.c < c2.c; }
-
-      static int 
-      compare(const char_type* s1, const char_type* s2, size_t n)
-      { return memcmp(s1, s2, n); }
-
-      static size_t
-      length(const char_type* s)
-      { return strlen(reinterpret_cast<const char*>(s)); }
-
-      static const char_type* 
-      find(const char_type* s, size_t n, const char_type& a)
-      { return static_cast<const char_type*>(memchr(s, a.c, n)); }
-
-      static char_type* 
-      move(char_type* s1, const char_type* s2, size_t n)
-      {
-	memmove(s1, s2, n);
-	return s1;
-      }
-
-      static char_type* 
-      copy(char_type* s1, const char_type* s2, size_t n)
-      {
-	memcpy(s1, s2, n);
-	return s1;
-      }
-
-      static char_type* 
-      assign(char_type* s, size_t n, char_type a)
-      {
-	memset(s, a.c, n);
-	return s;
-      }
-
-      static char_type 
-      to_char_type(const int_type& c)
-      {
-	char_type ret;
-	ret.c = static_cast<unsigned char>(c.i);
-	return ret;
-      }
-
-      static int_type 
-      to_int_type(const char_type& c)
-      {
-	int_type ret;
-	ret.i = c.c;
-	return ret;
-      }
-
-      static bool 
-      eq_int_type(const int_type& c1, const int_type& c2)
-      { return c1.i == c2.i; }
-
-      static int_type 
-      eof()
-      {
-	int_type n;
-	n.i = -10;
-	return n;
-      }
-
-      static int_type 
-      not_eof(const int_type& c)
-      {
-	if (eq_int_type(c, eof()))
-	  return int_type();
-	return c;
-      }
-    };
-} // namespace std
-
 #endif // _GLIBCXX_TESTSUITE_HOOKS_H
 
